@@ -16,8 +16,8 @@ class CovidModel(BaseModel):
     active: int = Field(0, alias="Active")
     deaths: int = Field(0, alias="Deaths")
     recovered: int = Field(0, alias="Recovered")
-    latitude: float = Field(..., alias="Lat")
-    longitude: float = Field(..., alias="Long_")
+    latitude: float = Field(None, alias="Lat")
+    longitude: float = Field(None, alias="Long_")
     last_update: int = Field(0, alias="Last_Update")
 
 
